@@ -93,6 +93,9 @@ class App(object):
     def disable_forced_linear_workflow(self):
         return False
 
+    def force_mfa_for_all_users(self):
+        return False
+
     def default_app_home_page_config(self):
         return {
             'content_app_name_header': '',
@@ -416,6 +419,16 @@ class AppWithDataSets(App):
         """
         return False
 
+    def force_mfa_for_all_users(self):
+        """(Optional) Force all users who log into app to use multi-factor authentication (MFA).
+
+        If a user logs in who does not have MFA enabled, they will be redirected to the MFA setup page. They will have to setup MFA before they can access the apps content.
+
+        :returns: Default of False
+        :rtype: boolean
+        """
+        return False
+
     def get_page_title(self):
         """(Optional) Set the title for the webpage. In most browsers, used as text in the tab title. Default is 'Tropofy'.
 
@@ -423,8 +436,6 @@ class AppWithDataSets(App):
         """
         return 'Tropofy'
 
-
-
     def _get_app_init_config(self, **kwargs):
         """Return config options at the App level. These options are applied to the app on page load (not dynamic beyond this).
 
@@ -580,7 +591,7 @@ class Step(object):
                 pass  # widget has no attribute embedded_widgets. Will be caught more often that not (in Python, exceptions are not exceptional!)
 
     def _construct_widget(self, widget, num_cols_in_gui=12):
-        widget.allocate_id()
+        widget._allocate_id()
         widget.num_cols_in_gui = min(num_cols_in_gui, 12)
         self.widgets.append(widget)
 
@@ -602,5 +613,5 @@ class Step(object):
             'uniqueDivId': self.get_unique_div_id(),
             'helpText': self.get_jsonifiable_help_text(),
             'hideNavigation': self.hide_navigation,
-            'widgets': [widget.serialise(**kwargs) for widget in self.get_ordered_widgets()]
+            'widgets': [widget._serialise(**kwargs) for widget in self.get_ordered_widgets()]
         }
