@@ -172,7 +172,7 @@ class DataSetMixin(DynamicSchemaMixin):
 
 
 class JsonStrFormats():
-    TIME = '%H:%M:%S'
+    TIME = '%H:%M:%S'  # TODO: Should make these ISO compliant. Would make hooking into 3rd party libs easier (eg Google Charts).
     DATE = '%Y-%m-%d'
     DATETIME = '%Y-%m-%d %H:%M:%S'
 
