@@ -17,31 +17,44 @@ from tropofy.database.tropofy_orm import ExtendedJsonEncoder
 import pkg_resources
 import pyramid.httpexceptions as exc
 from pyramid.response import Response
-from pyramid import threadlocal
 from pyramid.security import authenticated_userid, remember, forget
 from pyramid.view import view_config, forbidden_view_config, notfound_view_config
 
 
-def route_url_to_gui_server():
-    request = threadlocal.get_current_request()
+def route_url_to_gui_server(request):
     return request.registry.settings.get('custom.gui_server_url') + request.path
 
 
-def proxy_request(data, url=None):
-    return post_to_gui_server(url=url if url else route_url_to_gui_server(), data=data)
+def proxy_request(request, data=None, url=None):
+    data = data if data else {}
+    return post_to_gui_server(
+        request=request,
+        url=url if url else route_url_to_gui_server(request),
+        data=data
+    )
 
 
-def post_to_gui_server(url, data):
-    request = threadlocal.get_current_request()
-    key = request.app.get_published_license_key() if request.app and request.app.get_published_license_key() else request.registry.settings.get('custom.license_key')
-    data.update({
+def post_to_gui_server(request, url, data):
+    app = request.app
+    key = app.get_published_license_key() if app and app.get_published_license_key() else request.registry.settings.get('custom.license_key')
+    core_data = {
         'license_key': key,
         'authenticated_user': authenticated_userid(request),
         'client_ip': request.client_addr,
         'tropofy_version': pkg_resources.get_distribution("tropofy").version,
-    })
+    }
+
+    if app:
+        core_data.update({
+            'app_name': app.name,
+            'app_icon_url': app.get_icon_url(),
+            'page_title': app.get_page_title(),
+            'force_mfa_for_all_users': app.force_mfa_for_all_users(),
+        })
+
+    core_data.update(data)  # So it's possible to override core_data attributes in data.
     
-    response = requests.post(url, data=json.dumps(data, cls=ExtendedJsonEncoder), headers={'Content-type': 'application/json', 'Accept': 'text/plain'})
+    response = requests.post(url, data=json.dumps(core_data, cls=ExtendedJsonEncoder), headers={'Content-type': 'application/json', 'Accept': 'text/plain'})
     check_response_for_success(response)
     return response
 
@@ -49,6 +62,7 @@ def post_to_gui_server(url, data):
 def log_activity(request, description):
     url = request.registry.settings.get('custom.gui_server_url') + '/' + request.app.url_name + '/log_activity'
     proxy_request(
+        request=request,
         data={'description': description, 'from_compute_node': True},
         url=url
     )
@@ -57,20 +71,16 @@ def log_activity(request, description):
 @view_config(route_name='run_app', permission='run_app')
 def run_app(request):
     app = request.app
-    emulator_dict = {
-        'get_app_name': app.name,
-        'get_step_groups': [step_group.serialise(app=app, authenticated_user=authenticated_userid(request)) for step_group in app.get_ordered_step_groups()],
-        'get_app_icon_url': app.get_icon_url(),
-        'get_app_init_config': app._get_app_init_config(authenticated_user=authenticated_userid(request)),
-        'page_title': app.get_page_title(),
-    }
-    result = proxy_request({'emulator_dict': emulator_dict})
+    result = proxy_request(request, data={
+        'step_groups': [step_group.serialise(app=app, authenticated_user=authenticated_userid(request)) for step_group in app.get_ordered_step_groups()],
+        'app_init_config': app._get_app_init_config(authenticated_user=authenticated_userid(request)),
+    })
     return Response(result.content)
 
 
 def get_url_location(request, route_name, app_url_name):
     if request.registry.settings.get('custom.force_redirects_to_https'):
-        # Need to do this because current AWS setup routes through LB to HTTP so request.schema always HTTPS
+        # Need to do this because current AWS setup routes through LB to HTTP so request.schema always HTTP
         return request.route_url(route_name, app_url_name=app_url_name, _scheme='HTTPS', _port=443)
     return request.route_url(route_name, app_url_name=app_url_name, _scheme=request.scheme, _port=request.host_port)
 
@@ -83,35 +93,25 @@ def redirect_to_run_app(request):
         raise exc.HTTPNotFound()
 
 
-@view_config(route_name='update_widget_to_db', renderer='json', permission='run_app')
-def update_widget_to_db(request):
-    response = request.widget.update_to_db(data=dict(request.POST), data_set_id=request.data_set_id, oper=request.matchdict['oper'], data_set=request.data_set)
+@view_config(route_name='update_widget', renderer='json', permission='run_app')
+def update_widget(request):
+    response = request.widget._update(request=request, data=dict(request.POST), oper=request.matchdict['oper'], data_set=request.data_set)
     if request.matchdict['oper'] == 'needs_text_response':
         request.response.content_type = 'text/plain'
     return response
 
 
-@view_config(route_name='update_widget_from_db', renderer='json', permission='run_app')
-def update_widget_from_db(request):
-    return request.widget.update_from_db(data=dict(request.POST), data_set_id=request.data_set_id, oper=request.matchdict['oper'], data_set=request.data_set)
-
-
-@view_config(route_name='refresh_widget_from_db', renderer='json')  # , xhr=True, renderer='json', permission='run_app')
-def refresh_widget_from_db(request):
-    widget_parameters = request.widget.refresh_from_db(data_set=request.data_set, request=request)
-    if request.widget.get_type() is "KMLMapWidget":  # too much to send up and back
-        response = Response(widget_parameters['get_kml'])
+@view_config(route_name='refresh_widget', renderer='json')  # , xhr=True, renderer='json', permission='run_app')
+def refresh_widget(request):
+    widget_parameters = request.widget._refresh(request=request, data_set=request.data_set)
+    if request.widget._get_type() is "KMLMapWidget":  # too much to send up and back
+        response = Response(widget_parameters['kml'])
         response.content_type = 'text/xml'  # Must explicitly set for ie
         return response
-    elif request.widget.get_type() is "CustomExportWidget":  # too much to send up and back
-        response = Response(widget_parameters['get_data'])
+    elif request.widget._get_type() is "CustomExportWidget":  # too much to send up and back
+        response = Response(widget_parameters['data'])
         response.content_type = 'text/plain'  # Must explicitly set for ie
         return response
-    elif request.widget.get_type() in ["ChartWidget"]:  # Send to GUI server for processing.
-        data = {'widget_type': request.widget.get_type(), 'widget_parameters': widget_parameters}
-        response = proxy_request(data)
-        response = json.loads(response.text) # Todo: Change to response.content ? 
-        return response
     else:
         return widget_parameters
 
@@ -170,32 +170,50 @@ def login(request):
     data = {
         'login': request.POST.get('login'),
         'password': request.POST.get('password'),
+        'totp_token': request.POST.get('totp_token'),
     }
 
-    if proxy_request(data).status_code == 200:
+    if proxy_request(request, data).status_code == 200:
         headers = remember(request, request.POST['login'])
         request.response.headerlist.extend(headers)
         return {'success': True}
 
 
+@forbidden_view_config(renderer='string')
 @view_config(route_name='logout', renderer='string')
 def logout(request):
     headers = forget(request)
-
-    mako_render_dict = request.app.get_home_page_configuration()
-    mako_render_dict.update({
+    data = request.app.get_home_page_configuration()
+    data.update({
         'login_screen_default_is_create_account': request.app.is_login_screen_default_create_account(),
-        'page_title': request.app.get_page_title(),
     })
-    data = {'mako_render_dict': mako_render_dict}
-    url = request.registry.settings.get('custom.gui_server_url') + '/' + request.app.url_name + '/homepage'
-    result = proxy_request(data, url)
+    result = proxy_request(
+        request,
+        data=data,
+        url=request.registry.settings.get('custom.gui_server_url') + '/' + request.app.url_name + '/homepage',
+    )
     return Response(result.content, headers=headers)
 
 
-@forbidden_view_config(renderer='string')
-def forbidden(request):
-    return exc.HTTPFound(location=get_url_location(request, route_name='logout', app_url_name=request.matchdict.get('app_url_name')))
+@view_config(context=exc.HTTPUnauthorized)
+@view_config(route_name='manage_account', renderer='string')
+def manage_account(request):
+    url = request.registry.settings.get('custom.gui_server_url') + '/' + request.app.url_name + '/manage_account'
+    result = proxy_request(request, url=url)
+    return Response(result.content)
+
+
+@view_config(context=exc.HTTPNotAcceptable)
+@view_config(route_name='manage_mfa', renderer='string')
+def manage_mfa(request):
+    url = request.registry.settings.get('custom.gui_server_url') + '/' + request.app.url_name + '/manage_mfa'
+    result = proxy_request(request, url=url)
+    return Response(result.content)
+
+
+# @forbidden_view_config(renderer='string')
+# def forbidden(request):
+#     return exc.HTTPFound(location=get_url_location(request, route_name='logout', app_url_name=request.matchdict.get('app_url_name')))
 
 
 @notfound_view_config()
@@ -218,18 +236,26 @@ def check_response_for_success(response):
     if response.status_code == 403:
         raise exc.HTTPForbidden()
 
-    # (2) HTTPNotFound thrown on GUI server - e.g. if app_name is not valid
+    # (2) HTTPUnauthorized thrown on GUI server - using Temp password and have to change it.
+    if response.status_code == 401:
+        raise exc.HTTPUnauthorized()
+
+    # (3) HTTPNotFound thrown on GUI server - e.g. if app_name is not valid
     if response.status_code == 404:
         raise exc.HTTPNotFound()
 
-    # (3) NonCompatibleComputeNodeException thrown on GUI server.
+    # (4) HTTPNotAcceptable thrown on GUI server - users must be using MFA and user isn't.
+    if response.status_code == 406:
+        raise exc.HTTPNotAcceptable()
+
+    # (5) NonCompatibleComputeNodeException thrown on GUI server.
     if response.status_code == 409:
         pass  # Let response get rendered.
 
     if response.status_code == 500:
         raise Exception(response.text)
 
-    # (2) Tropofy caught failure
+    # (6) Tropofy caught failure
     success = True
     message = ""
     try:
