@@ -15,17 +15,17 @@ from tropofy.widgets import Chart
 
 
 class TableChart(Chart):  # Default Chart Interface
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.TABLE
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "name": ("string", "Name"),
             "salary": ("number", "Salary"),
             "full_time": ("boolean", "Full Time Employee")
         }
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         return [
             {"name": "Mike", "salary": (10000, "$10,000"), "full_time": True},
             {"name": "Jim", "salary": (800, "$800"), "full_time": False},
@@ -33,28 +33,28 @@ class TableChart(Chart):  # Default Chart Interface
             {"name": "Bob", "salary": (7000, "$7,000"), "full_time": True}
         ]
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["name", "salary", "full_time"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "salary"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {'title': 'Employee Details'}
 
 
 class ExampleBarChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.BARCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "year": ("string", "Year"),
             "sales": ("number", "Sales"),
             "expenses": ("number", "Expenses")
         }
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         return [
             {"year": 2004, "sales": 1000, "expenses": 400},
             {"year": 2005, "sales": 1170, "expenses": 460},
@@ -62,13 +62,13 @@ class ExampleBarChart(Chart):
             {"year": 2007, "sales": 1030, "expenses": 540}
         ]
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["year", "sales", "expenses"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "year"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {
             'title': 'Company Performance',
             'vAxis': {
@@ -79,19 +79,19 @@ class ExampleBarChart(Chart):
 
 
 class ExamplePieChart(Chart):
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {'title': 'Daily Schedule'}
 
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.PIECHART
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["task", "hours"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "task"
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         return [
             {"task": 'Work', "hours": 11},
             {"task": 'Eat', "hours": 2},
@@ -100,7 +100,7 @@ class ExamplePieChart(Chart):
             {"task": 'Sleep', "hours": 7},
         ]
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "task": ("string", "Task"),
             "hours": ("number", "Hours per Day")
