@@ -13,7 +13,7 @@ or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
 
 from tropofy.database.db_manager import DbManager
 from tropofy.widgets import Form
-from tropofy.widgets.grid_widget import grid_widget
+from tropofy.widgets import grid_widget
 from sqlalchemy.sql.expression import desc, or_, cast
 from sqlalchemy import String
 from sqlalchemy.orm import _mapper_registry
@@ -51,7 +51,7 @@ class SimpleGrid(grid_widget.GridWidget):
             widget_subscriptions=widget_subscriptions
         )
 
-    def get_type(self):
+    def _get_type(self):
         return 'SimpleGrid'
 
     def add_new_row(self, data, data_set_id):
@@ -121,7 +121,7 @@ class SimpleGrid(grid_widget.GridWidget):
     def get_col_names_to_not_search_on(self, data_set):
         return self.get_hidden_column_names()
 
-    def grid_is_editable(self):
+    def grid_is_editable(self, **kwargs):
         return self.editable
 
 
