@@ -60,41 +60,31 @@ class Widget(object):
         # Add checking that trigger_event_name is a valid event. Perhaps with an enum pattern?
         self.event_subscriptions[trigger_event_name] += subscribed_actions
 
-    def allocate_id(self):
+    def _allocate_id(self):
         self.id = Widget.widget_indexer
         Widget.widget_indexer += 1
         assert self.id not in Widget.widget_dict
         Widget.widget_dict[self.id] = self
         self.num_cols_in_gui = 12
 
-    def get_unique_div_id(self):
-        return "widget-" + str(self.id)
-
-    def get_type(self):
+    def _get_type(self):
         '''Unique identifier for the widget'''
         pass
 
-    def get_info_to_download(self, data_set, as_attachment):
-        return ''
-
-    def update_to_db(self, data, data_set_id, oper='', data_set=None):
-        """Update some data from the widget to the db."""
+    def _update(self, request, data, oper, data_set, **kwargs):
+        """Update the widget - not a full refresh."""
         pass
 
-    def update_from_db(self, data, data_set_id, oper='', data_set=None):
-        """Update some data from the server to the widget."""
-        pass
-
-    def refresh_from_db(self, data_set, request):
+    def _refresh(self, request, data_set, **kwargs):
         """Refresh all data for widget."""
         pass
 
-    def add_embedded_widget(self, name, widget):
+    def _add_embedded_widget(self, name, widget):
         
         if not hasattr(self, 'embedded_widgets'):
             self.embedded_widgets = {}
 
-        widget.allocate_id()
+        widget._allocate_id()
         self.embedded_widgets.update({name: widget})
 
     __mapper_args__ = {  # TODO: Remove these? No longer using SQLA here....
@@ -102,7 +92,29 @@ class Widget(object):
         'polymorphic_on': type
     }
 
-    def is_hidden(self):  # Todo: Could be changed to include data_set and added to all widget.refresh_from_db. Would require standardisation of refresh_from_db though.
+    def _serialise(self, **kwargs):
+        '''Dict representation for easy conversion to JSON.'''
+        event_subscriptions = self.event_subscriptions if hasattr(self, 'event_subscriptions') else {}
+        serialised_event_subscriptions = {}
+        for event_name, subscribed_actions in event_subscriptions.iteritems():
+            serialised_event_subscriptions.update({event_name: []})
+            for action in subscribed_actions:
+                serialised_event_subscriptions[event_name].append({
+                    'widget_id': action.widget.id,
+                    'name': action.name
+                })
+
+        return {
+            'id': self.id,
+            'type': self._get_type(),
+            'numColsInGui': self.num_cols_in_gui,
+            'embeddedWidgetSpecs': {key: value._serialise(**kwargs) for key, value in self.embedded_widgets.iteritems()} if hasattr(self, 'embedded_widgets') else {},
+            'eventSubscriptions': serialised_event_subscriptions,
+            'isHidden': self.is_hidden(**kwargs),
+            'enablePrint': self.enable_print(**kwargs),
+        }
+
+    def is_hidden(self, **kwargs):
         """Hides a widget. Can be shown through events. Default: False.
 
         Warning: this is evaluated once on app launch. After this, visibility must be managed by events.
@@ -120,28 +132,6 @@ class Widget(object):
          """
         return str(self.id)
 
-    def serialise(self, **kwargs):
-        '''Dict representation for easy conversion to JSON.'''        
-        event_subscriptions = self.event_subscriptions if hasattr(self, 'event_subscriptions') else {}
-        serialised_event_subscriptions = {}
-        for event_name, subscribed_actions in event_subscriptions.iteritems():            
-            serialised_event_subscriptions.update({event_name: []})
-            for action in subscribed_actions:
-                serialised_event_subscriptions[event_name].append({
-                    'widget_id': action.widget.id,
-                    'name': action.name
-                })
-
-        return {
-            'id': self.id,
-            'type': self.get_type(),
-            'numColsInGui': self.num_cols_in_gui,
-            'embeddedWidgetSpecs': {key: value.serialise(**kwargs) for key, value in self.embedded_widgets.iteritems()} if hasattr(self, 'embedded_widgets') else {},
-            'eventSubscriptions': serialised_event_subscriptions,
-            'isHidden': self.is_hidden(),
-            'enablePrint': self.enable_print(**kwargs),
-        }
-
     def enable_print(self, **kwargs):
         """Shows a button on the widget to print it."""
         # TODO: Make widget accept **kwargs. Then pass a 'printable' option.
