@@ -140,13 +140,13 @@ class MapArcOutput(KMLMap):
 
 
 class WeightInCutPieChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.PIECHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {"item": ("string", "Item"), "weight": ("number", "Weight")}
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         arcs = data_set.query(MaxWCutArc).all()
         arc_weight_total = sum((arc.weight for arc in arcs))
         arc_weight_in_cut = sum((arc.weight for arc in arcs if arc.in_cut))
@@ -157,13 +157,13 @@ class WeightInCutPieChart(Chart):
         ]
         return items
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["item", "weight"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "weight"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         arcs = data_set.query(MaxWCutArc).all()
         arc_weight_total = sum((arc.weight for arc in arcs))
         arc_weight_in_cut = sum((arc.weight for arc in arcs if arc.in_cut))
