@@ -67,14 +67,14 @@ class MyApp(AppWithDataSets):
         return {"Demo data set": load_example_data}
 
     def get_icon_url(self):
-        return 'http://www.tropofy.com/static/css/img/tropofy_example_app_icons/histogram_3d.png'
+        return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/histogram_3d.png'
 
     def get_home_page_content(self):
         return {
             'content_app_name_header': '''
             <div>
             <span style="vertical-align: middle;">Plotting in 3D</span>
-            <img src="http://www.tropofy.com/static/css/img/tropofy_example_app_icons/histogram_3d.png" alt="main logo" style="width:15%">
+            <img src="https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/histogram_3d.png" alt="main logo" style="width:15%">
             </div>''',
 
             'content_single_column_app_description': '''
