@@ -48,7 +48,7 @@ class OutputPlot(StaticImage):
 
 
 class SelectScenario(Form):
-    def get_form_elements(self, data_set):
+    def get_form_elements(self, data_set, **kwargs):
         scenarios = data_set.query(Scenario).all()
         scenario_names = [s.name for s in scenarios]
 
