@@ -149,14 +149,14 @@ class MyBulkGeocoderApp(AppWithDataSets):
         data_set.add_all(addresses)
 
     def get_icon_url(self):
-        return 'http://www.tropofy.com/static/css/img/tropofy_example_app_icons/geocoding.png'
+        return 'https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/geocoding.png'
 
     def get_home_page_content(self):
         return {
             'content_app_name_header': '''
             <div>
             <span style="vertical-align: middle;">Batch Geocoding</span>
-            <img src="http://www.tropofy.com/static/css/img/tropofy_example_app_icons/geocoding.png" alt="main logo" style="width:15%">
+            <img src="https://s3-ap-southeast-2.amazonaws.com/tropofy.com/static/css/img/tropofy_example_app_icons/geocoding.png" alt="main logo" style="width:15%">
             </div>''',
 
             'content_single_column_app_description': '''
