@@ -39,17 +39,17 @@ class MyKMLMap(KMLMap):
 
 
 class PerformanceBarChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.BARCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "year": ("string", "Year"),
             "sales": ("number", "Sales"),
             "expenses": ("number", "Expenses")
         }
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         results = []
         years = [y for r in data_set.query(Performance.year).distinct() for y in r]
         for year in years:
@@ -61,13 +61,13 @@ class PerformanceBarChart(Chart):
             })
         return results
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["year", "sales", "expenses"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "year"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {
             'title': 'Company Performance',
             'vAxis': {
